Stan Math Library: stan/math/prim/mat/fun/divide.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
divide.hpp File Reference
`#include <boost/type_traits/is_arithmetic.hpp>`
`#include <boost/utility/enable_if.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<int R, int C, typename T >
boost::enable_if_c< boost::is_arithmetic< T >::value, Eigen::Matrix< double, R, C > >::type | stan::math::divide (const Eigen::Matrix< double, R, C > &m, T c)
| Return specified matrix divided by specified scalar. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.